# CRIRES_SET_PREFIX(PREFIX)
#---------------------------
AC_DEFUN([CRIRES_SET_PREFIX],
[
    unset CDPATH
    # make $PIPE_HOME the default for the installation
    AC_PREFIX_DEFAULT($1)

    if test "x$prefix" = "xNONE"; then
        prefix=$ac_default_prefix
        ac_configure_args="$ac_configure_args --prefix $prefix"
    fi

    if test "x$exec_prefix" = "xNONE"; then
        exec_prefix=$prefix
    fi

])


# CRIRES_SET_VERSION_INFO(VERSION, [CURRENT], [REVISION], [AGE])
#----------------------------------------------------------------
# Setup various version information, especially the libtool versioning
AC_DEFUN([CRIRES_SET_VERSION_INFO],
[
    crires_version=`echo "$1" | sed -e 's/[[a-z,A-Z]].*$//'`

    crires_major_version=`echo "$crires_version" | \
        sed 's/\([[0-9]]*\).\(.*\)/\1/'`
    crires_minor_version=`echo "$crires_version" | \
        sed 's/\([[0-9]]*\).\([[0-9]]*\)\(.*\)/\2/'`
    crires_micro_version=`echo "$crires_version" | \
        sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\3/'`

    if test -z "$crires_major_version"; then crires_major_version=0
    fi

    if test -z "$crires_minor_version"; then crires_minor_version=0
    fi

    if test -z "$crires_micro_version"; then crires_micro_version=0
    fi

    CRIRES_VERSION="$crires_version"
    CRIRES_MAJOR_VERSION=$crires_major_version
    CRIRES_MINOR_VERSION=$crires_minor_version
    CRIRES_MICRO_VERSION=$crires_micro_version

    if test -z "$4"; then CRIRES_INTERFACE_AGE=0
    else CRIRES_INTERFACE_AGE="$4"
    fi

    CRIRES_BINARY_AGE=`expr 100 '*' $CRIRES_MINOR_VERSION + $CRIRES_MICRO_VERSION`
    CRIRES_BINARY_VERSION=`expr 10000 '*' $CRIRES_MAJOR_VERSION + \
                          $CRIRES_BINARY_AGE`

    AC_SUBST(CRIRES_VERSION)
    AC_SUBST(CRIRES_MAJOR_VERSION)
    AC_SUBST(CRIRES_MINOR_VERSION)
    AC_SUBST(CRIRES_MICRO_VERSION)
    AC_SUBST(CRIRES_INTERFACE_AGE)
    AC_SUBST(CRIRES_BINARY_VERSION)
    AC_SUBST(CRIRES_BINARY_AGE)

    AC_DEFINE_UNQUOTED(CRIRES_MAJOR_VERSION, $CRIRES_MAJOR_VERSION,
                       [CRIRES major version number])
    AC_DEFINE_UNQUOTED(CRIRES_MINOR_VERSION, $CRIRES_MINOR_VERSION,
                       [CRIRES minor version number])
    AC_DEFINE_UNQUOTED(CRIRES_MICRO_VERSION, $CRIRES_MICRO_VERSION,
                       [CRIRES micro version number])
    AC_DEFINE_UNQUOTED(CRIRES_INTERFACE_AGE, $CRIRES_INTERFACE_AGE,
                       [CRIRES interface age])
    AC_DEFINE_UNQUOTED(CRIRES_BINARY_VERSION, $CRIRES_BINARY_VERSION,
                       [CRIRES binary version number])
    AC_DEFINE_UNQUOTED(CRIRES_BINARY_AGE, $CRIRES_BINARY_AGE,
                       [CRIRES binary age])

    ESO_SET_LIBRARY_VERSION([$2], [$3], [$4])
])


# CRIRES_SET_PATHS
#------------------
# Define auxiliary directories of the installed directory tree.
AC_DEFUN([CRIRES_SET_PATHS],
[

    if test -z "$plugindir"; then
        plugindir='${libdir}/esopipes-plugins/${PACKAGE}-${VERSION}'
    fi

    if test -z "$privatelibdir"; then
        privatelibdir='${libdir}/${PACKAGE}-${VERSION}'
    fi

    htmldir='${datadir}/doc/esopipes/${PACKAGE}-${VERSION}/html'
    
    if test -z "$pipedocsdir"; then
        pipedocsdir='${datadir}/doc/esopipes/${PACKAGE}-${VERSION}/'
    fi

    if test -z "$configdir"; then
       configdir='${datadir}/${PACKAGE}/config'
    fi

    AC_SUBST(plugindir)
    AC_SUBST(privatelibdir)
    AC_SUBST(htmldir)
    AC_SUBST(pipedocsdir)
    AC_SUBST(configdir)


    # Define a preprocesor symbol for the plugin search paths

    AC_DEFINE_UNQUOTED(CRIRES_PLUGIN_DIR, "esopipes-plugins",
                       [Plugin directory tree prefix])


    eval plugin_dir="$plugindir"
    plugin_path=`eval echo $plugin_dir | \
                sed -e "s/\/${PACKAGE}-${VERSION}.*$//"`

    AC_DEFINE_UNQUOTED(CRIRES_PLUGIN_PATH, "$plugin_path",
                       [Absolute path to the plugin directory tree])

])


# CRIRES_CREATE_SYMBOLS
#-----------------------
# Define include and library related makefile symbols
AC_DEFUN([CRIRES_CREATE_SYMBOLS],
[

    # Symbols for package include file and library search paths

    CRIRES_INCLUDES='-I$(top_srcdir)/crires -I$(top_srcdir)/irplib'
    CRIRES_LDFLAGS='-L$(top_builddir)/crires'

    all_includes='$(CRIRES_INCLUDES) $(CPL_INCLUDES) $(EXTRA_INCLUDES)'
    all_ldflags='$(CRIRES_LDFLAGS) $(CPL_LDFLAGS) $(EXTRA_LDFLAGS)'

    # Library aliases

    LIBCRIRES='$(top_builddir)/crires/libcrires.la'
    LIBIRPLIB='$(top_builddir)/irplib/libirplib.la'

    # Substitute the defined symbols

    AC_SUBST(CRIRES_INCLUDES)
    AC_SUBST(CRIRES_LDFLAGS)

    AC_SUBST(LIBCRIRES)
    AC_SUBST(LIBIRPLIB)

    # Check for CPL and user defined libraries
    AC_REQUIRE([CPL_CHECK_LIBS])
    AC_REQUIRE([ESO_CHECK_EXTRA_LIBS])

    all_includes='$(CRIRES_INCLUDES) $(CPL_INCLUDES) $(EXTRA_INCLUDES)'
    all_ldflags='$(CRIRES_LDFLAGS) $(CPL_LDFLAGS) $(EXTRA_LDFLAGS)'

    AC_SUBST(all_includes)
    AC_SUBST(all_ldflags)
])
